km3pipe.time.Timer
==================

.. currentmodule:: km3pipe.time

.. autoclass:: Timer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Timer.__init__
      ~Timer.log
      ~Timer.start
      ~Timer.stop
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Timer.cpu_seconds
      ~Timer.seconds
   
   